@@ -5,7 +5,7 @@ use warnings;
 use vars qw($VERSION);
 use 5.008;
 
-$VERSION = '1.09';
+$VERSION = '1.10';
 
 =begin markdown
 
@@ -21,7 +21,7 @@ Business::Tax::VAT - perform European VAT calculations
 
 =head1 VERSION
 
-This pod describes version 1.09
+This pod describes version 1.10
 
 =head1 SYNOPSIS
 
@@ -66,6 +66,9 @@ sub _item {
 
 package Business::Tax::VAT::Price;
 
+use vars qw($VERSION);
+$VERSION = '1.10';
+
 our %RATE;
 
 __PACKAGE__->_calculate_vat_rates();
@@ -235,6 +238,16 @@ VAT in the UK), then you can (locally) set the rate by assigning to
   local $Business::Tax::VAT::Price::RATE{uk} = 0 
     if ($product_type eq 'book' and $country eq 'uk');
 
+=head1 DYNAMICAALY ADDING A COUNTRY
+
+If you want to add your own country, do the following:
+
+    my $vat = Business::Tax::VAT->new(qw/gb/);
+
+    $Business::Tax::VAT::Price::RATE{'gb'} = 20;
+
+    my $price = $vat->item(102 => 'gb');
+
 =head1 SEE ALSO
 
 =over
@@ -256,13 +269,15 @@ Please direct all correspondence regarding this module to:
 
 =over
 
+=item * Documentation added in release 1.10 based on question from Tom Kirkpatrick
+
 =item * Sam Kington, patches leading to release of 1.07 and 1.08
 
 =back
 
 =head1 COPYRIGHT
 
-  Copyright (C) 2001-2014 Tony Bowden.
+  Copyright (C) 2001-2015 Tony Bowden.
 
   This program is free software; you can redistribute it and/or modify it under
   the terms of the GNU General Public License; either version 2 of the License,
